# Example Project

For a quick start, lets look at a simple example of creating and publishing a library using two dependencies.

First, create a standard python project:

```
$ tree
.
├── README.md
├── setup.cfg
├── src
│   └── example-pygradle-project
│       └── __init__.py
└── test
    └── test_example.py
```

*Note the lack of a setup.py, more on this in a moment...*

If you have not already installed Gradle (preferably version 3.0+, but we strive to be backwards compatible with 2.10+), feel free to do so now, [documentation here](https://docs.gradle.org/current/userguide/installation.html). Or, if you are using osx and brew you can simply `brew install gradle`.

Add a top level `build.gradle` file that leverages {py}gradle:

```
plugins {
    id "com.linkedin.python-sdist" version "0.3.9"
}

dependencies {
    python 'pypi:requests:2.9.1'
    test 'pypi:mock:1.3.0'
}

repositories {
    // This repository is provided for example purposes only
    pyGradlePyPi()
}
```

Now, create your gradle wrapper:

```
$ gradle wrapper --gradle-version 3.0
```

The contents of your `setup.py`, `setup.cfg` and other boilerplate can be whatever you like. However, to maintain backwards compatibility with non-gradle projects, you can generate a setup.py using {py}gradle which will create a `pinned.txt` of the dependency tree generated by gradle: 

```
$ ./gradlew generateSetupPy
```

The `setup.py` in this example was created using the above task, by default the "setup" section at the bottom is commented out, so please look it over before continuing. For this example we want to uncomment the whole section at the bottom of the setup.py.

*Note:* The `generateSetupPy` task should only be used to bootstrap a project and should be checked in to a project.

---

You are now ready to run your build!

```
$ ./gradlew build
```

Feel free to check out some of the other bundled tasks:

```
$ ./gradlew tasks
:tasks

------------------------------------------------------------
All tasks runnable from root project
------------------------------------------------------------

Build tasks
-----------
assemble - Assembles the outputs of this project.
build - Assembles and tests this project.
clean - Deletes the build directory.

Build Setup tasks
-----------------
init - Initializes a new Gradle build. [incubating]
wrapper - Generates Gradle wrapper files. [incubating]

Documentation tasks
-------------------
buildDocsHtml - Generate Sphinx documentation in html format
buildDocsJson - Generate Sphinx documentation in json format
generateSetupPy - Writes the suggested setup.py out to disk. This will overwrite any existing setup.py

Help tasks
----------
components - Displays the components produced by root project 'example-pygradle-project'. [incubating]
dependencies - Displays all dependencies declared in root project 'example-pygradle-project'.
dependencyInsight - Displays the insight into a specific dependency in root project 'example-pygradle-project'.
help - Displays a help message.
model - Displays the configuration model of root project 'example-pygradle-project'. [incubating]
projects - Displays the sub-projects of root project 'example-pygradle-project'.
properties - Displays the properties of root project 'example-pygradle-project'.
tasks - Displays the tasks runnable from root project 'example-pygradle-project'.

Verification tasks
------------------
check - Runs all checks.

Other tasks
-----------
coverage
flake8Checkstyle
packageDocs
packageJsonDocs

Rules
-----
Pattern: clean<TaskName>: Cleans the output files of a task.
Pattern: build<ConfigurationName>: Assembles the artifacts of a configuration.
Pattern: upload<ConfigurationName>: Assembles and uploads the artifacts belonging to a configuration.

To see all tasks and more detail, run gradlew tasks --all

To see more detail about a task, run gradlew help --task <task>

BUILD SUCCESSFUL

Total time: 3.297 secs
```

Enjoy!
